" Vim syntax file
" Language:     otpl Oran Template 1.0
" Maintainer:   Chris Monson <chris@bouncingchairs.net>
" URL:          None yet
" Email:        Subject: Give me OTPL Syntax!
" Last Change:  2001 Mar 10


" Remove any old syntax stuff hanging around
syn clear

if !exists("main_syntax")
  let main_syntax = 'otpl'
endif

if &filetype == 'otpl_html'
    so $VIMRUNTIME/syntax/html.vim
    syn cluster htmlPreproc add=@otplRegion
elseif &filetype == 'otpl_apache'
    so $VIMRUNTIME/syntax/apachestyle.vim
    syn cluster apachestylePreProc add=@otplRegion
elseif &filetype == 'otpl_js'
    so $VIMRUNTIME/syntax/javascript.vim
    syn cluster htmlPreproc add=@otplRegion
endif

syn case match

" Hanging end tags are tags that occur on the end of the line.  They change
"   color to remind people that the endline will be eaten up with the rest
"   of the tag.  This should help people to remember to add an extra newline
"   when one is desired.
syntax match OParen /[)(]/ contained
syntax match OBlockBlankError /\S\+/ contained
syntax match OHangEnd /?>$/ contained
syntax match OHangEndColon /:\s\{-}?>$/ contained
syntax match OHangEndError /?>$/ contained
syntax match OHangEndColonError /:\s\{-}?>$/ contained

syntax match OEnd /?>./ contained
syntax match OEndColon /:\s\{-}?>./ contained
syntax match OEndError /?>./ contained
syntax match OEndColonError /:\s\{-}?>./ contained

"syntax match OCallDef /\S\+\s*(.\{-})/ contained

syntax cluster OETag contains=OHangEnd,OEnd
syntax cluster OETagColon contains=OHangEndColon,OEndColon
syntax cluster OETagError contains=OHangEndError,OEndError
syntax cluster OETagColonError contains=OHangEndColonError,OEndColonError

syntax match OStart /<?=/ contained

syntax cluster OTagGrp contains=@OETag,@OETagColonError,OStart
syntax cluster OTagColonGrp contains=@OETagColon,@OETagError,OStart

syntax keyword OOp contained in
syntax keyword OName contained echo if elif endif for endfor def enddef
syntax keyword OName contained call inc break continue
syntax keyword ONameElse contained else
syntax keyword ONameComment contained comment
syntax keyword ONameExec contained exec
syntax keyword ONameInclude contained inc rawinc

syntax match OForFunction /for_\(index\|list\|count\|is_last\|is_first\)\s*(\s*\d*\s*)/ contains=OParen contained

syntax region OTagShortcut start=/<?=/ end=/?>/ contains=@OTagGrp,OForFunction,OParen keepend

syntax region OTagCondBlock start=/<?=\(if\|elif\)\(\s\|$\)/ end=/:\s*?>/ contains=@OTagColonGrp,OName keepend

syntax region OTagElseBlock start=/<?=else/ end=/\s*:\s*?>/ contains=@OTagColonGrp,OBlockBlankError,ONameElse keepend

syntax region OTagDefBlock start=/<?=\(def\)\(\s\|$\)/ end=/:\s*?>/ contains=@OTagColonGrp,OName,OParen keepend

syntax region OTagForBlock start=/<?=\(for\)\(\s\|$\)/ end=/:\s*?>/ contains=@OTagColonGrp,OName,OOp,OForFunction keepend

syntax region OTagEndBlock start=/<?=\(endif\|endfor\|enddef\|break\|continue\)/ end=/?>/ contains=@OTagGrp,OBlockBlankError,OName keepend

syntax region OTagCall start=/<?=call\(\s\|$\)/ end=/?>/ contains=@OTagGrp,OName,OForFunction keepend

syntax region OTagEcho start=/<?=echo\(\s\|$\)/ end=/?>/ contains=@OTagGrp,OName,OForFunction,OParen keepend

syntax region OTagComment start=/<?=comment\(\s\|$\)/ end=/?>/ contains=@OTagGrp,ONameComment keepend

syntax region OTagExec start=/<?=exec\(\s\|$\)/ end=/?>/ contains=@OTagGrp,OForFunction,ONameExec keepend

syntax region OTagInclude start=/<?=\(inc\|rawinc\)\(\s\|$\)/ end=/?>/ contains=@OTagGrp,ONameInclude keepend

" Cluster this region together so that it is easy to add to the HTML
" preprocessor stuff (and any other preprocessor stuff, since this stuff
" is always processed first).
syntax cluster otplRegion contains=OTagShortcut,OTagCondBlock,OTagElseBlock,OTagDefBlock,OTagForBlock,OTagEndBlock,OTagCall,OTagEcho,OTagComment,OTagExec,OTagInclude

" Link the highlight groups together to make editing them easy
hi link OTagShortcut        otplTag
hi link OTagCondBlock       otplTag
hi link OTagElseBlock       otplTag
hi link OTagDefBlock        otplTag
hi link OTagForBlock        otplTag
hi link OTagEndBlock        otplTag
hi link OTagCall            otplTag
hi link OTagEcho            otplTag
hi link OTagComment         otplTag
hi link OTagExec            otplTag
hi link OTagInclude         otplTag

hi link OBlockBlankError    otplError
hi link OHangEndError       otplError
hi link OHangEndColonError  otplError
hi link OEndError           otplError
hi link OEndColonError      otplError

hi link OName               otplIdent
hi link ONameElse           otplIdent
hi link ONameComment        otplIdent
hi link ONameExec           otplIdent
hi link ONameInclude        otplIdent

hi link OOp                 otplOperator
hi link OParen              otplOperator
hi link OForFunction        otplOperator
"hi link OCallDef            otplOperator

hi link OHangEnd            otplHangDelimiter
hi link OHangEndColon       otplHangDelimiter
hi link OEnd                otplDelimiter
hi link OEndColon           otplDelimiter
hi link OStart              otplDelimiter

hi otplTag guifg=white guibg=#555555 term=reverse ctermbg=3
hi otplError guifg=white guibg=red term=bold ctermbg=red
hi otplOperator guifg=Green guibg=#555555 gui=bold term=reverse ctermbg=3
hi otplIdent guifg=#ffff60 gui=bold guibg=#555555 term=reverse ctermbg=3

hi otplHangDelimiter guifg=Cyan gui=bold guibg=#555555 term=reverse ctermbg=3
hi otplDelimiter guifg=Orange guibg=#555555 term=reverse ctermbg=3
